@@ -24,6 +24,8 @@ __all__ = [
     'changes_sections',
     'changes_by_author',
     'changelog_add_entry',
+    'changeblock_add_line',
+    'changeblock_ensure_first_line',
     'all_sha_prefixed',
     'any_long_lines',
     'rewrap_change',
@@ -39,6 +41,7 @@ from debian.changelog import (
     Changelog,
     ChangelogCreateError,
     ChangelogParseError,
+    format_date,
     get_maintainer,
     Version,
     )
@@ -74,6 +77,22 @@ class ChangelogEditor(Editor):
     def changelog(self):
         return self._parsed
 
+    def __getitem__(self, i):
+        return self.changelog[i]
+
+    def new_block(self, *args, **kwargs):
+        return self.changelog.new_block(*args, **kwargs)
+
+    def add_entry(
+            self,
+            summary: List[str],
+            maintainer: Optional[Tuple[str, str]] = None,
+            timestamp: Optional[datetime] = None,
+            urgency: str = 'low') -> None:
+        return changelog_add_entry(
+            self.changelog, summary=summary, maintainer=maintainer,
+            timestamp=timestamp, urgency=urgency)
+
 
 def changes_sections(
         changes: List[str]
@@ -309,16 +328,20 @@ def changelog_add_entry(
             date=format_datetime(timestamp),
             distributions='UNRELEASED',
             changes=[''])
+    changeblock_add_line(cl[0], summary)
+
+
+def changeblock_add_line(block, lines):
     wrapper = TextWrapper(INITIAL_INDENT)
-    cl[0]._changes.extend(wrapper.wrap(summary[0]))
-    for line in summary[1:]:
+    block._changes.extend(wrapper.wrap(lines[0]))
+    for line in lines[1:]:
         prefix = len(INITIAL_INDENT) * ' '
         m = re.match(r'^[  ]*[\+\-\*] ', line)
         if m:
             prefix += m.group(0)
             line = line[len(m.group(0)):]
-        cl[0]._changes.extend(TextWrapper(prefix).wrap(line))
-    cl[0]._changes.append('')
+        block._changes.extend(TextWrapper(prefix).wrap(line))
+    block._changes.append('')
 
 
 def strip_changelog_message(changes: List[str]) -> List[str]:
@@ -404,3 +427,35 @@ def all_sha_prefixed(cb: ChangeBlock) -> bool:
         else:
             return False
     return (sha_prefixed > 0)
+
+
+def changeblock_ensure_first_line(block, line, maintainer=None):
+    """Ensure that the first line matches the specified line.
+    """
+    if maintainer is None:
+        maintainer_name, maintainer_email = get_maintainer()
+    else:
+        maintainer_name, maintainer_email = maintainer
+    if maintainer_name is None or maintainer_email is None:
+        raise ValueError(
+            'unable to determine maintainer details and none specified')
+    if block._changes[0]:
+        raise ValueError('first block line not empty')
+    line = '  * ' + line
+    if block._changes[1] == line:
+        return
+    block._changes.insert(1, line)
+    if block._changes[2].startswith('  ['):
+        block._changes.insert(2, '')
+    elif parseaddr(block.author)[0] != maintainer_name:
+        block._changes.insert(2, '  [ %s ]' % parseaddr(block.author)[0])
+        block._changes.insert(2, '')
+        block.author = "%s <%s>" % (maintainer_name, maintainer_email)
+
+
+def release(cl, distribution="unstable", timestamp=None, localtime=True):
+    """Create a release for a changelog file.
+    """
+    if cl[0].distributions == 'UNRELEASED':
+        cl[0].distributions = distribution
+        cl[0].date = format_date(timestamp=timestamp, localtime=localtime)
